@@ -442,13 +442,15 @@ nm_main_dialog_run (NmMainDialog *self, int caller)
     if (caller == NM_STATUS_MENU) {
         gtk_widget_hide(priv->advanced_button);
     }
-    
-    NmSettings *settings  = nm_settings_new();
-    gchar *mode = nm_settings_get_value (settings, NULL, NM_SETTINGS_GROUP, NM_SETTINGS_MODE);
-    if (mode != NULL && !strcmp(mode, NM_SETTINGS_MODE_ADVANCED)) {
-        nm_main_dialog_switch_to_advanced(self);
+    else { /* Only restore the previous mode if the caller is the control panel */
+        NmSettings *settings  = nm_settings_new();
+        gchar *mode = nm_settings_get_value (settings, NULL, NM_SETTINGS_GROUP, NM_SETTINGS_MODE);
+        if (mode != NULL && !strcmp(mode, NM_SETTINGS_MODE_ADVANCED)) {
+            nm_main_dialog_switch_to_advanced(self);
+        }
+        g_free(mode);
     }
-    g_free(mode);
+
 
     while (!done) {
 
