@@ -141,10 +141,15 @@ nm_usb_setup_enable (NmUsbSetup *self, gchar *mode)
         gtk_combo_box_set_active (GTK_COMBO_BOX(priv->checkbutton), NM_USB_NETWORK);
     }
     else if (!strcmp(mode, NM_USB_MASS_STORAGE_LABEL)) {
-        gtk_combo_box_set_active (GTK_COMBO_BOX(priv->checkbutton), NM_USB_MASS_STORAGE);;
+        gtk_combo_box_set_active (GTK_COMBO_BOX(priv->checkbutton), NM_USB_MASS_STORAGE);
     }
     else {
-        gtk_combo_box_set_active(GTK_COMBO_BOX(priv->checkbutton), NM_USB_HOST_MODE);
+#ifdef DIABLO
+    	gtk_combo_box_set_active(GTK_COMBO_BOX(priv->checkbutton), NM_USB_HOST_MODE);
+#endif
+#ifdef FREMANTLE
+    	gtk_combo_box_set_active(GTK_COMBO_BOX(priv->checkbutton), NM_USB_PC_SUITE);
+#endif        
     }
     g_debug("[%s]", __FUNCTION__);
 }
@@ -494,14 +499,14 @@ usb_setup_check_enabled (NmUsbSetup *self)
     if (nm_usb_utils_is_loaded ()) {
 
         nm_usb_setup_enable (self, NM_USB_NETWORK_LABEL);
-/*        nm_usb_setup_enable_cb (GTK_COMBO_BOX (priv->checkbutton), self);*/
-        return TRUE;
+    } else if (nm_usb_utils_is_host_mode ()) {
+    	
+    	nm_usb_setup_enable (self, NM_USB_HOST_MODE_LABEL);
     } else {
-
+    	
         nm_usb_setup_enable (self, NM_USB_MASS_STORAGE_LABEL);
-/*        nm_usb_setup_enable_cb (GTK_TOGGLE_BUTTON (priv->checkbutton), self);*/
-        return FALSE;
     }
+    return TRUE;
 }
 
 void
