@@ -66,14 +66,37 @@ nm_usb_utils_unload (void)
 gboolean 
 nm_usb_utils_put_in_host_mode (void)
 {
+#ifdef DIABLO
     gint status = system("sudo /usr/sbin/nm-usb-setup host");
+#endif
+#ifdef FREMANTLE
+    gint status = system("sudo /usr/sbin/nm-usb-setup suite");
+#endif	
+    return status == 0;
+}
+
+gboolean
+nm_usb_utils_is_host_mode ()
+{
+	gint status = 1;
+	
+#ifdef FREMANTLE
+    status = system("sudo /usr/sbin/nm-usb-setup suite_status");
+    g_debug("[%s] - Status: %d", __FUNCTION__, status);
+#endif
+    
     return status == 0;
 }
 
 gboolean 
 nm_usb_utils_put_in_otg_mode (void)
 {
+#ifdef DIABLO
     gint status = system("sudo /usr/sbin/nm-usb-setup otg");
+#endif
+#ifdef FREMANTLE
+    gint status = nm_usb_utils_unload();
+#endif
     return status == 0;
 }
 
