@@ -353,15 +353,13 @@ nm_wlan_setup_apply_changes (NmConnWidget *self)
         if (is_active) {
             nm_wlan_utils_deactivate ();
         }
-        
-
+   
         gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_TYPE, NM_WLAN_DEFAULT_TYPE , NULL);
         gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_IPV4_TYPE, NM_WLAN_DEFAULT_IPV4_TYPE , NULL);
         gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_HIDDEN, NM_WLAN_DEFAULT_HIDDEN , NULL);
         gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_NAME, NM_WLAN_DEFAULT_NAME , NULL);
         gconf_client_set_string (gcClient, NM_GCONF_KEY_WLAN_SECURITY, NM_WLAN_DEFAULT_SECURITY , NULL);
-    
-        
+      
         value = gtk_entry_get_text (GTK_ENTRY (priv->wep_entry));
         int wep_size = strlen(value);
         g_debug("[%s] - wep key: %s , size: %d", __FUNCTION__, value, wep_size);
@@ -408,12 +406,7 @@ nm_wlan_setup_apply_changes (NmConnWidget *self)
         }
     } else if (is_active) {
 
-        if (nm_wlan_utils_deactivate ()) {
-
-/*            hildon_banner_show_information(NULL, NULL,*/
-/*                                            "WLAN Ad-Hoc network disabled");*/
-        } else {
-
+        if (!nm_wlan_utils_deactivate ()) {
             return FALSE;
         }
     }
